@@ -3,7 +3,7 @@ package Net::FullAuto::ISets::Amazon::Hadoop_is;
 ### OPEN SOURCE LICENSE - GNU AFFERO PUBLIC LICENSE Version 3.0 #######
 #
 #    Net::FullAuto - Powerful Network Process Automation Software
-#    Copyright © 2000-2015  Brian M. Kelly
+#    Copyright © 2000-2016  Brian M. Kelly
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as
@@ -24,6 +24,7 @@ package Net::FullAuto::ISets::Amazon::Hadoop_is;
 
 our $VERSION='0.01';
 our $DISPLAY='Apache™ Hadoop®';
+our $CONNECT='ssh';
 our $defaultInstanceType='t2.micro';
 
 use 5.005;
@@ -58,10 +59,12 @@ my $configure_hadoop=sub {
    my $server_host_block=$_[3]||'';
    my $handle=$main::aws->{$server_type}->[$cnt]->[1];
    my ($stdout,$stderr,$exitcode,$error)=('','','','');
-   ($stdout,$stderr)=$handle->cmd("sudo apt-get update",'__display__');
+   ($stdout,$stderr)=$handle->cmd(
+      "sudo apt-get -o Dpkg::Progress=true update 2>&1",'__display__');
    ($stdout,$stderr)=$handle->cmd(
       "sudo add-apt-repository -y ppa:webupd8team/java",'__display__');
-   ($stdout,$stderr)=$handle->cmd("sudo apt-get update",'__display__');
+   ($stdout,$stderr)=$handle->cmd(
+      "sudo apt-get -o Dpkg::Progress=true update 2>&1",'__display__');
    ($stdout,$stderr)=$handle->cmd(
       "echo debconf shared/accepted-oracle-license-v1-1 select true | ".
       "sudo debconf-set-selections");
@@ -69,7 +72,8 @@ my $configure_hadoop=sub {
       "echo debconf shared/accepted-oracle-license-v1-1 seen true | ".
       "sudo debconf-set-selections");
    ($stdout,$stderr)=$handle->cmd(
-      "sudo apt-get -y install oracle-jdk7-installer",'__display__');
+      "sudo apt-get -o Dpkg::Progress=true -y --force-yes install ".
+      "oracle-jdk7-installer 2>&1",'__display__');
    my $gcnt=2;my $md5='';my $targz='';my $hadoop_mirror='';
    while (--$gcnt) {
       my $url='http://www.apache.org/dyn/closer.cgi/hadoop/common/';
@@ -89,20 +93,23 @@ my $configure_hadoop=sub {
       unless ($hadoop_mirror=~/^http/) {
          print "Can't get Apache™ Hadoop® mirror -> $hadoop_mirror\n\n",
                "after 5 attempts\n";
-         cleanup();
+         &Net::FullAuto::FA_Core::cleanup;
       }
-      ($stdout,$stderr)=$handle->cmd("wget -qO- $hadoop_mirror/stable");
+      ($stdout,$stderr)=$handle->cmd("wget -qO- ".
+         "$hadoop_mirror/hadoop/common/stable");
       my $flag=0;
       foreach my $line (split "\n",$stdout) {
          chomp($line);
          if ($line=~/(?<!src)[.]tar[.]gz["]/) {
             $targz=$line;
             $targz=~s/^.*[Hh][Rr][Ee][Ff]=["](.*?)["].*$/$1/;
-            ($stdout,$stderr)=$handle->cmd("wget $targz");
+            ($stdout,$stderr)=$handle->cmd(
+               "sudo wget --random-wait --progress=dot $targz 2>&1");
          } elsif ($line=~/(?<!src)[.]tar[.]gz[.]mds/) {
             $md5=$line;
             $md5=~s/^.*[Hh][Rr][Ee][Ff]=["](.*?)["].*$/$1/;
-            ($stdout,$stderr)=$handle->cmd("wget $md5");
+            ($stdout,$stderr)=$handle->cmd(
+               "sudo wget --random-wait --progress=dot $md5 2>&1");
             last unless $stderr;
          }
       } last unless $stderr;
@@ -135,29 +142,49 @@ END
 
    print $download_hadoop;sleep 10;
    foreach my $dc (0..2) {
-      ($stdout,$stderr,$exitcode)=$handle->cmd("wget $hadoop_mirror/stable/$targz",
+      ($stdout,$stderr,$exitcode)=$handle->cmd(
+         "sudo wget --random-wait --progress=dot ".
+         "$hadoop_mirror/hadoop/common/stable/$targz 2>&1",
          '__display__');
       print "wget ERROR: $stderr\n" if $stderr;
-      ($stdout,$stderr)=$handle->cmd("wget $hadoop_mirror/stable/$md5",
+      ($stdout,$stderr)=$handle->cmd(
+         "sudo wget --random-wait --progress=dot ".
+         "$hadoop_mirror/hadoop/common/stable/$md5 2>&1",
          '__display__');
       ($stdout,$stderr)=$handle->cmd("cat $md5");
       my $checksum=$stdout;
-      $checksum=~s/^.*MD5\s*[=]\s*(.*?)\n.*$/$1/s;
+      $checksum=~s/^.*MD5\s*[=]\s*(.*?)\n$targz.*$/$1/s;
       $checksum=~s/\s//g;
       ($stdout,$stderr)=$handle->cmd("md5sum -c - <<<\"$checksum $targz\"",
          '__display__');
       unless ($stderr) {
          print(qq{ + CHECKSUM Test for $targz *PASSED* \n});
+      } else {
+         if ($dc<3) {
+            ($stdout,$stderr)=$handle->cmd("sudo rm -rvf $md5",'__display__');
+            ($stdout,$stderr)=$handle->cmd("sudo rm -rvf $targz",'__display__');
+            next; 
+         }
+         print "FATAL ERROR! : CHECKSUM Test for $targz *FAILED* ",
+               "after $dc attempts\n";
+         &Net::FullAuto::FA_Core::cleanup;
+      }
+      ($stdout,$stderr)=$handle->cmd("sudo tar zxvf $targz -C /opt",
+         '__display__');
+      $stderr.=$stdout;
+      if (-1==index $stderr,'tar: Unexpected EOF in archive') {
          last;
       } else {
-         next unless $dc==2;
-         print "FATAL ERROR! : CHECKSUM Test for $targz *FAILED* after $dc attempts\n";
+         if ($dc<3) {
+            ($stdout,$stderr)=$handle->cmd("sudo rm -rvf $md5",'__display__');
+            ($stdout,$stderr)=$handle->cmd("sudo rm -rvf $targz",'__display__');
+            next;
+         }
+         print "FATAL ERROR! : tar: Unexpected EOF in archive ",
+               "after $dc attempts\n";
       }
    }
-   ($stdout,$stderr)=$handle->cmd("sudo tar zxvf $targz -C /opt",
-      '__display__');
-   ($stdout,$stderr)=$handle->cmd("sudo rm -rvf $md5",
-      '__display__');
+   ($stdout,$stderr)=$handle->cmd("sudo rm -rvf $md5",'__display__');
    ($stdout,$stderr)=$handle->cmd("sudo rm -rvf $targz",'__display__');
    $targz=~s/[.]tar[.]gz//;
    my $id=$main::aws->{$server_type}->[$cnt]->[0]->{InstanceId};
@@ -218,17 +245,16 @@ END
       ($stdout,$stderr)=$handle->cmd(
          "sudo chmod -R 600 /home/ubuntu/.ssh/*",
          '__display__');
-      ($stdout,$stderr)=$sftp_handle->cmd(
-         "get /home/ubuntu/.ssh/id_rsa.pub",'__display__');
+      ($stdout,$stderr)=$sftp_handle->get(
+         '/home/ubuntu/.ssh/id_rsa.pub');
    } else {
-      ($stdout,$stderr)=$sftp_handle->cmd(
-         "put /tmp/id_rsa.pub",'__display__');
+      ($stdout,$stderr)=$sftp_handle->put('id_rsa.pub');
       ($stdout,$stderr)=$handle->cmd(
          'cat ~/id_rsa.pub >> ~/.ssh/authorized_keys','__display__');
       ($stdout,$stderr)=$handle->cmd(
          "sudo chmod -R 600 /home/ubuntu/.ssh/*",
          '__display__');
-      unlink "/tmp/id_rsa.pub" if $cnt==3;
+      unlink "id_rsa.pub" if $cnt==3;
    }
    # http://sed.sourceforge.net/sed1line.txt - useful one line sed scripts
    ($stdout,$stderr)=$handle->cmd('sudo sed -i \'s#[$][{]JAVA_HOME[}]#'.
@@ -357,7 +383,7 @@ END
          $test_output.=$output;
          last if $test_output=~/$prompt/;
          print $output;
-         if ($test_output=~/authenticity of host/) {
+         if ($test_output=~/[(]yes\/no[)][?]/) {
             $master->{_cmd_handle}->print("yes");
             $test_output='';
          }
@@ -379,7 +405,7 @@ END
           |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ ©
 
 
-   Copyright © 2000-2015  Brian M. Kelly  Brian.Kelly@FullAuto.com
+   Copyright © 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
 
 END
       eval {
@@ -448,11 +474,12 @@ my $standup_hadoop=sub {
    Net::FullAuto::FA_Core::handle_error($error) if $error
       && $error!~/already exists/;
    my $cnt=0;
-   $pem_file=~s/\.pem\s*$//s;
+   my $pemfile=$pem_file;
+   $pemfile=~s/\.pem\s*$//s;
    if (exists $main::aws->{'Hadoop.Apache.org'}) {
       my $g=get_aws_security_id('HadoopSecurityGroup');
       my $c="aws ec2 run-instances --image-id $i --count 1 ".
-         "--instance-type $type --key-name $pem_file ".
+         "--instance-type $type --key-name $pemfile ".
          "--security-group-ids $g --subnet-id $s";
       if ($#{$main::aws->{'Hadoop.Apache.org'}}==0) {
          launch_server('Hadoop.Apache.org',$cnt,$hadoop,$u,$c,
